@@ -15,6 +15,9 @@
 #include <openrct2/GameState.h>
 #include <openrct2/Input.h>
 #include <openrct2/OpenRCT2.h>
+#include <openrct2/SpriteIds.h>
+#include <openrct2/drawing/Rectangle.h>
+#include <openrct2/interface/ColourWithFlags.h>
 #include <openrct2/interface/Cursors.h>
 #include <openrct2/localisation/Formatter.h>
 #include <openrct2/management/Research.h>
@@ -24,17 +27,17 @@
 #include <openrct2/object/ObjectRepository.h>
 #include <openrct2/ride/RideData.h>
 #include <openrct2/ride/RideManager.hpp>
-#include <openrct2/sprites.h>
 #include <openrct2/ui/WindowManager.h>
 #include <openrct2/world/Scenery.h>
 
+using namespace OpenRCT2::Drawing;
+
 namespace OpenRCT2::Ui::Windows
 {
 #pragma region Widgets
 
-    static constexpr int32_t WW = 600;
-    static constexpr int32_t WH = 400;
-    static constexpr StringId WINDOW_TITLE = STR_INVENTION_LIST;
+    static constexpr ScreenSize kWindowSize = { 600, 400 };
+    static constexpr StringId kWindowTitle = STR_INVENTION_LIST;
 
     enum
     {
@@ -52,21 +55,21 @@ namespace OpenRCT2::Ui::Windows
     };
 
     // clang-format off
-    static constexpr Widget _inventionListWidgets[] = {
-        WINDOW_SHIM(WINDOW_TITLE, WW, WH),
-        MakeWidget({  0,  43}, {600, 357}, WindowWidgetType::Resize,  WindowColour::Secondary                                             ),
-        MakeTab   ({  3,  17}                                                                                               ),
-        MakeWidget({  4,  56}, {368, 161}, WindowWidgetType::Scroll,  WindowColour::Secondary, SCROLL_VERTICAL                            ),
-        MakeWidget({  4, 231}, {368, 157}, WindowWidgetType::Scroll,  WindowColour::Secondary, SCROLL_VERTICAL                            ),
-        MakeWidget({431, 106}, {114, 114}, WindowWidgetType::FlatBtn, WindowColour::Secondary                                             ),
-        MakeWidget({375, 343}, {220,  14}, WindowWidgetType::Button,  WindowColour::Secondary, STR_MOVE_ALL_TOP                           ),
-        MakeWidget({375, 358}, {220,  14}, WindowWidgetType::Button,  WindowColour::Secondary, STR_MOVE_ALL_BOTTOM                        ),
-        MakeWidget({375, 373}, {220,  14}, WindowWidgetType::Button,  WindowColour::Secondary, STR_RANDOM_SHUFFLE,  STR_RANDOM_SHUFFLE_TIP),
-    };
+    static constexpr auto _inventionListWidgets = makeWidgets(
+        makeWindowShim(kWindowTitle, kWindowSize),
+        makeWidget({  0,  43}, {600, 357}, WidgetType::resize,  WindowColour::secondary                                             ),
+        makeTab   ({  3,  17}                                                                                                       ),
+        makeWidget({  4,  56}, {368, 161}, WidgetType::scroll,  WindowColour::secondary, SCROLL_VERTICAL                            ),
+        makeWidget({  4, 231}, {368, 157}, WidgetType::scroll,  WindowColour::secondary, SCROLL_VERTICAL                            ),
+        makeWidget({431, 106}, {114, 114}, WidgetType::flatBtn, WindowColour::secondary                                             ),
+        makeWidget({375, 343}, {220,  14}, WidgetType::button,  WindowColour::secondary, STR_MOVE_ALL_TOP                           ),
+        makeWidget({375, 358}, {220,  14}, WidgetType::button,  WindowColour::secondary, STR_MOVE_ALL_BOTTOM                        ),
+        makeWidget({375, 373}, {220,  14}, WidgetType::button,  WindowColour::secondary, STR_RANDOM_SHUFFLE,  STR_RANDOM_SHUFFLE_TIP)
+    );
 
-    static constexpr Widget _inventionListDragWidgets[] = {
-        MakeWidget({0, 0}, {150, 14}, WindowWidgetType::ImgBtn, WindowColour::Primary),
-    };
+    static constexpr auto _inventionListDragWidgets = makeWidgets(
+        makeWidget({0, 0}, {150, 14}, WidgetType::imgBtn, WindowColour::primary)
+    );
     // clang-format on
 
 #pragma endregion
@@ -93,44 +96,44 @@ namespace OpenRCT2::Ui::Windows
         }
 
         // Set research required for rides in use
-        for (const auto& ride : GetRideManager())
+        const auto& gameState = getGameState();
+        for (const auto& ride : RideManager(gameState))
         {
             Editor::SetSelectedObject(
-                ObjectType::Ride, ride.subtype, ObjectSelectionFlags::Selected | ObjectSelectionFlags::InUse);
+                ObjectType::ride, ride.subtype, ObjectSelectionFlags::Selected | ObjectSelectionFlags::InUse);
         }
     }
 
     static void DrawResearchItem(
-        DrawPixelInfo& dpi, const ResearchItem& researchItem, const int16_t& width, const ScreenCoordsXY& screenCoords,
+        RenderTarget& rt, const ResearchItem& researchItem, const int16_t& width, const ScreenCoordsXY& screenCoords,
         StringId format, TextPaint textPaint)
     {
         const StringId itemNameId = researchItem.GetName();
         int16_t columnSplitOffset = width / 2;
 
-        if (researchItem.type == Research::EntryType::Ride
+        if (researchItem.type == Research::EntryType::ride
             && !GetRideTypeDescriptor(researchItem.baseRideType).HasFlag(RtdFlag::listVehiclesSeparately))
         {
-            const StringId rideTypeName = GetRideNaming(
-                                              researchItem.baseRideType, *GetRideEntryByIndex(researchItem.entryIndex))
+            const StringId rideTypeName = GetRideNaming(researchItem.baseRideType, GetRideEntryByIndex(researchItem.entryIndex))
                                               .Name;
 
             // Draw group name
             auto ft = Formatter();
             ft.Add<StringId>(rideTypeName);
-            DrawTextEllipsised(dpi, screenCoords, columnSplitOffset - 11, format, ft, textPaint);
+            DrawTextEllipsised(rt, screenCoords, columnSplitOffset - 11, format, ft, textPaint);
 
             // Draw vehicle name
             ft = Formatter();
             ft.Add<StringId>(itemNameId);
             DrawTextEllipsised(
-                dpi, { screenCoords + ScreenCoordsXY{ columnSplitOffset, 0 } }, columnSplitOffset - 11, format, ft, textPaint);
+                rt, { screenCoords + ScreenCoordsXY{ columnSplitOffset, 0 } }, columnSplitOffset - 11, format, ft, textPaint);
         }
         else
         {
             // Scenery group, flat ride or shopdis
             auto ft = Formatter();
             ft.Add<StringId>(itemNameId);
-            DrawTextEllipsised(dpi, screenCoords, width, format, ft, textPaint);
+            DrawTextEllipsised(rt, screenCoords, width, format, ft, textPaint);
         }
     }
 
@@ -146,27 +149,24 @@ namespace OpenRCT2::Ui::Windows
         ResearchItem* _selectedResearchItem;
 
     public:
-        void OnOpen() override
+        void onOpen() override
         {
             ResearchRidesSetup();
 
-            SetWidgets(_inventionListWidgets);
-            InitScrollWidgets();
-            selected_tab = 0;
+            setWidgets(_inventionListWidgets);
+            initScrollWidgets();
+            selectedTab = 0;
             _selectedResearchItem = nullptr;
 
-            min_width = WW;
-            min_height = WH;
-            max_width = WW * 2;
-            max_height = WH * 2;
+            WindowSetResize(*this, kWindowSize, { kWindowSize.width * 2, kWindowSize.height * 2 });
         }
 
-        void OnClose() override
+        void onClose() override
         {
             ResearchRemoveFlags();
 
             // When used in-game (as a cheat)
-            if (!(gScreenFlags & SCREEN_FLAGS_EDITOR))
+            if (!isInEditorMode())
             {
                 gSilentResearch = true;
                 ResearchResetCurrentItem();
@@ -174,79 +174,77 @@ namespace OpenRCT2::Ui::Windows
             }
         }
 
-        void OnMouseUp(WidgetIndex widx) override
+        void onMouseUp(WidgetIndex widx) override
         {
             switch (widx)
             {
                 case WIDX_CLOSE:
-                    Close();
+                    close();
                     break;
                 case WIDX_RANDOM_SHUFFLE:
                     ResearchItemsShuffle();
-                    Invalidate();
+                    invalidate();
                     break;
                 case WIDX_MOVE_ITEMS_TO_TOP:
                     ResearchItemsMakeAllResearched();
-                    InitScrollWidgets();
-                    Invalidate();
+                    initScrollWidgets();
+                    invalidate();
                     break;
                 case WIDX_MOVE_ITEMS_TO_BOTTOM:
                     ResearchItemsMakeAllUnresearched();
-                    InitScrollWidgets();
-                    Invalidate();
+                    initScrollWidgets();
+                    invalidate();
                     break;
             }
         }
 
-        void OnResize() override
+        void onResize() override
         {
-            if (width < min_width)
+            if (width < minWidth)
             {
-                Invalidate();
-                width = min_width;
+                invalidate();
+                width = minWidth;
             }
-            if (height < min_height)
+            if (height < minHeight)
             {
-                Invalidate();
-                height = min_height;
+                invalidate();
+                height = minHeight;
             }
         }
 
-        void OnUpdate() override
+        void onUpdate() override
         {
-            frame_no++;
-            OnPrepareDraw();
+            currentFrame++;
+            onPrepareDraw();
 
-            InvalidateWidget(WIDX_TAB_1);
+            invalidateWidget(WIDX_TAB_1);
 
             if (WindowEditorInventionsListDragGetItem() != nullptr)
                 return;
-
-            Invalidate();
         }
 
-        ScreenSize OnScrollGetSize(int32_t scrollIndex) override
+        ScreenSize onScrollGetSize(int32_t scrollIndex) override
         {
-            const auto& gameState = GetGameState();
+            const auto& gameState = getGameState();
             ScreenSize size{};
             if (scrollIndex == 0)
             {
-                size.height = static_cast<int32_t>(gameState.ResearchItemsInvented.size()) * kScrollableRowHeight;
+                size.height = static_cast<int32_t>(gameState.researchItemsInvented.size()) * kScrollableRowHeight;
             }
             else
             {
-                size.height = static_cast<int32_t>(gameState.ResearchItemsUninvented.size()) * kScrollableRowHeight;
+                size.height = static_cast<int32_t>(gameState.researchItemsUninvented.size()) * kScrollableRowHeight;
             }
             return size;
         }
 
-        void OnScrollMouseOver(int32_t scrollIndex, const ScreenCoordsXY& screenCoords) override
+        void onScrollMouseOver(int32_t scrollIndex, const ScreenCoordsXY& screenCoords) override
         {
             auto* researchItem = GetItemFromScrollY(scrollIndex == 0, screenCoords.y);
             if (researchItem != _selectedResearchItem)
             {
                 _selectedResearchItem = researchItem;
-                Invalidate();
+                invalidate();
 
                 // Prevent always-researched items from being highlighted when hovered over
                 if (researchItem != nullptr && researchItem->IsAlwaysResearched())
@@ -256,7 +254,7 @@ namespace OpenRCT2::Ui::Windows
             }
         }
 
-        void OnScrollMouseDown(int32_t scrollIndex, const ScreenCoordsXY& screenCoords) override
+        void onScrollMouseDown(int32_t scrollIndex, const ScreenCoordsXY& screenCoords) override
         {
             auto* researchItem = GetItemFromScrollY(scrollIndex == 0, screenCoords.y);
             if (researchItem == nullptr)
@@ -266,28 +264,28 @@ namespace OpenRCT2::Ui::Windows
             if (researchItem->IsAlwaysResearched())
                 return;
 
-            Invalidate();
+            invalidate();
 
             WindowEditorInventionsListDragOpen(researchItem, windowPos, widgets[WIDX_PRE_RESEARCHED_SCROLL].right);
         }
 
-        void OnScrollDraw(int32_t scrollIndex, DrawPixelInfo& dpi) override
+        void onScrollDraw(int32_t scrollIndex, Drawing::RenderTarget& rt) override
         {
-            const auto& gameState = GetGameState();
+            const auto& gameState = getGameState();
 
             // Draw background
             uint8_t paletteIndex = ColourMapA[colours[1].colour].mid_light;
-            GfxClear(dpi, paletteIndex);
+            GfxClear(rt, paletteIndex);
 
-            int16_t boxWidth = widgets[WIDX_RESEARCH_ORDER_SCROLL].width();
+            int16_t boxWidth = widgets[WIDX_RESEARCH_ORDER_SCROLL].width() - 1;
             int32_t itemY = -kScrollableRowHeight;
             auto* dragItem = WindowEditorInventionsListDragGetItem();
 
-            const auto& researchList = scrollIndex == 0 ? gameState.ResearchItemsInvented : gameState.ResearchItemsUninvented;
+            const auto& researchList = scrollIndex == 0 ? gameState.researchItemsInvented : gameState.researchItemsUninvented;
             for (const auto& researchItem : researchList)
             {
                 itemY += kScrollableRowHeight;
-                if (itemY + kScrollableRowHeight < dpi.y || itemY >= dpi.y + dpi.height)
+                if (itemY + kScrollableRowHeight < rt.y || itemY >= rt.y + rt.height)
                     continue;
 
                 if (_selectedResearchItem == &researchItem)
@@ -306,7 +304,7 @@ namespace OpenRCT2::Ui::Windows
                         bottom = itemY;
                     }
 
-                    GfxFilterRect(dpi, { 0, top, boxWidth, bottom }, FilterPaletteID::PaletteDarken1);
+                    Rectangle::filter(rt, { 0, top, boxWidth, bottom }, FilterPaletteID::paletteDarken1);
                 }
 
                 if (dragItem != nullptr && researchItem == *dragItem)
@@ -315,23 +313,23 @@ namespace OpenRCT2::Ui::Windows
                 // TODO: this parameter by itself produces very light text.
                 // It needs a {BLACK} token in the string to work properly.
                 ColourWithFlags colour = { COLOUR_BLACK };
-                FontStyle fontStyle = FontStyle::Medium;
-                auto darkness = TextDarkness::Regular;
+                FontStyle fontStyle = FontStyle::medium;
+                auto darkness = TextDarkness::regular;
 
                 if (researchItem.IsAlwaysResearched())
                 {
                     if (_selectedResearchItem == &researchItem && dragItem == nullptr)
-                        darkness = TextDarkness::ExtraDark;
+                        darkness = TextDarkness::extraDark;
                     else
-                        darkness = TextDarkness::Dark;
+                        darkness = TextDarkness::dark;
                     colour = colours[1].withFlag(ColourFlag::inset, true);
                 }
 
-                DrawResearchItem(dpi, researchItem, boxWidth, { 1, itemY }, STR_BLACK_STRING, { colour, fontStyle, darkness });
+                DrawResearchItem(rt, researchItem, boxWidth, { 1, itemY }, STR_BLACK_STRING, { colour, fontStyle, darkness });
             }
         }
 
-        CursorID OnCursor(WidgetIndex widx, const ScreenCoordsXY& screenCoords, CursorID fallback) override
+        CursorID onCursor(WidgetIndex widx, const ScreenCoordsXY& screenCoords, CursorID fallback) override
         {
             bool isInvented = false;
 
@@ -356,28 +354,28 @@ namespace OpenRCT2::Ui::Windows
             return fallback;
         }
 
-        void OnDraw(DrawPixelInfo& dpi) override
+        void onDraw(Drawing::RenderTarget& rt) override
         {
-            DrawWidgets(dpi);
+            drawWidgets(rt);
 
             // Tab image
             auto screenPos = windowPos + ScreenCoordsXY{ widgets[WIDX_TAB_1].left, widgets[WIDX_TAB_1].top };
-            GfxDrawSprite(dpi, ImageId(SPR_TAB_FINANCES_RESEARCH_0 + (frame_no / 2) % 8), screenPos);
+            GfxDrawSprite(rt, ImageId(SPR_TAB_FINANCES_RESEARCH_0 + (currentFrame / 2) % 8), screenPos);
 
             // Pre-researched items label
             screenPos = windowPos
                 + ScreenCoordsXY{ widgets[WIDX_PRE_RESEARCHED_SCROLL].left, widgets[WIDX_PRE_RESEARCHED_SCROLL].top - 11 };
-            DrawTextBasic(dpi, screenPos - ScreenCoordsXY{ 0, 1 }, STR_INVENTION_PREINVENTED_ITEMS);
+            DrawTextBasic(rt, screenPos - ScreenCoordsXY{ 0, 1 }, STR_INVENTION_PREINVENTED_ITEMS);
 
             // Research order label
             screenPos = windowPos
                 + ScreenCoordsXY{ widgets[WIDX_RESEARCH_ORDER_SCROLL].left, widgets[WIDX_RESEARCH_ORDER_SCROLL].top - 11 };
-            DrawTextBasic(dpi, screenPos - ScreenCoordsXY{ 0, 1 }, STR_INVENTION_TO_BE_INVENTED_ITEMS);
+            DrawTextBasic(rt, screenPos - ScreenCoordsXY{ 0, 1 }, STR_INVENTION_TO_BE_INVENTED_ITEMS);
 
             // Preview background
             auto& bkWidget = widgets[WIDX_PREVIEW];
-            GfxFillRect(
-                dpi,
+            Rectangle::fill(
+                rt,
                 { windowPos + ScreenCoordsXY{ bkWidget.left + 1, bkWidget.top + 1 },
                   windowPos + ScreenCoordsXY{ bkWidget.right - 1, bkWidget.bottom - 1 } },
                 ColourMapA[colours[1].colour].darkest);
@@ -390,9 +388,9 @@ namespace OpenRCT2::Ui::Windows
                 return;
 
             // Preview image
-            ObjectType objectEntryType = ObjectType::SceneryGroup;
-            if (researchItem->type == Research::EntryType::Ride)
-                objectEntryType = ObjectType::Ride;
+            ObjectType objectEntryType = ObjectType::sceneryGroup;
+            if (researchItem->type == Research::EntryType::ride)
+                objectEntryType = ObjectType::ride;
 
             auto chunk = ObjectEntryGetChunk(objectEntryType, researchItem->entryIndex);
             if (chunk == nullptr)
@@ -402,11 +400,11 @@ namespace OpenRCT2::Ui::Windows
             const auto* object = ObjectEntryGetObject(objectEntryType, researchItem->entryIndex);
             if (object != nullptr)
             {
-                DrawPixelInfo clipDPI;
+                RenderTarget clipDPI;
                 screenPos = windowPos + ScreenCoordsXY{ bkWidget.left + 1, bkWidget.top + 1 };
-                const auto clipWidth = bkWidget.width() - 1;
-                const auto clipHeight = bkWidget.height() - 1;
-                if (ClipDrawPixelInfo(clipDPI, dpi, screenPos, clipWidth, clipHeight))
+                const auto clipWidth = bkWidget.width() - 2;
+                const auto clipHeight = bkWidget.height() - 2;
+                if (ClipDrawPixelInfo(clipDPI, rt, screenPos, clipWidth, clipHeight))
                 {
                     object->DrawPreview(clipDPI, clipWidth, clipHeight);
                 }
@@ -420,12 +418,11 @@ namespace OpenRCT2::Ui::Windows
             StringId stringId = researchItem->GetName();
             auto ft = Formatter();
 
-            if (researchItem->type == Research::EntryType::Ride
+            if (researchItem->type == Research::EntryType::ride
                 && !GetRideTypeDescriptor(researchItem->baseRideType).HasFlag(RtdFlag::listVehiclesSeparately))
             {
                 drawString = STR_WINDOW_COLOUR_2_STRINGID_STRINGID;
-                StringId rideTypeName = GetRideNaming(
-                                            researchItem->baseRideType, *GetRideEntryByIndex(researchItem->entryIndex))
+                StringId rideTypeName = GetRideNaming(researchItem->baseRideType, GetRideEntryByIndex(researchItem->entryIndex))
                                             .Name;
                 ft.Add<StringId>(rideTypeName);
                 ft.Add<StringId>(stringId);
@@ -435,25 +432,22 @@ namespace OpenRCT2::Ui::Windows
                 ft.Add<StringId>(stringId);
             }
 
-            DrawTextEllipsised(dpi, screenPos, itemWidth, drawString, ft, { TextAlignment::CENTRE });
+            DrawTextEllipsised(rt, screenPos, itemWidth, drawString, ft, { TextAlignment::centre });
             screenPos.y += 15;
 
             // Item category
             screenPos.x = windowPos.x + widgets[WIDX_RESEARCH_ORDER_SCROLL].right + 4;
             ft = Formatter();
             ft.Add<StringId>(researchItem->GetCategoryInventionString());
-            DrawTextBasic(dpi, screenPos, STR_INVENTION_RESEARCH_GROUP, ft);
+            DrawTextBasic(rt, screenPos, STR_INVENTION_RESEARCH_GROUP, ft);
         }
 
-        void OnPrepareDraw() override
+        void onPrepareDraw() override
         {
-            pressed_widgets |= 1uLL << WIDX_PREVIEW;
-            pressed_widgets |= 1uLL << WIDX_TAB_1;
+            pressedWidgets |= 1uLL << WIDX_PREVIEW;
+            pressedWidgets |= 1uLL << WIDX_TAB_1;
 
-            widgets[WIDX_CLOSE].type = gScreenFlags & SCREEN_FLAGS_SCENARIO_EDITOR ? WindowWidgetType::Empty
-                                                                                   : WindowWidgetType::CloseBox;
-
-            ResizeFrameWithPage();
+            widgets[WIDX_CLOSE].type = gLegacyScene == LegacyScene::scenarioEditor ? WidgetType::empty : WidgetType::closeBox;
 
             int16_t scrollListHeight = (height - 88) / 2;
 
@@ -495,11 +489,11 @@ namespace OpenRCT2::Ui::Windows
                 auto& widget = widgets[widgetIndex];
                 if (widgetIndex == WIDX_PRE_RESEARCHED_SCROLL || widgetIndex == WIDX_RESEARCH_ORDER_SCROLL)
                 {
-                    gPressedWidget.widget_index = widgetIndex;
+                    gPressedWidget.widgetIndex = widgetIndex;
                     int32_t outScrollArea{};
                     ScreenCoordsXY outScrollCoords{};
                     int32_t outScrollId{};
-                    WidgetScrollGetPart(*this, &widget, screenCoords, outScrollCoords, &outScrollArea, &outScrollId);
+                    widgetScrollGetPart(*this, &widget, screenCoords, outScrollCoords, &outScrollArea, &outScrollId);
                     if (outScrollArea == SCROLL_PART_VIEW)
                     {
                         const auto isInvented = outScrollId == 0;
@@ -517,7 +511,7 @@ namespace OpenRCT2::Ui::Windows
             return item == _selectedResearchItem;
         }
 
-        // hack to fix #17544: OnScrollMouseOver never gets called while dragging
+        // hack to fix #17544: onScrollMouseOver never gets called while dragging
         void SetSelectedResearchItem(ResearchItem* item)
         {
             _selectedResearchItem = item;
@@ -525,9 +519,9 @@ namespace OpenRCT2::Ui::Windows
 
         void MoveResearchItem(const ResearchItem& item, ResearchItem* beforeItem, bool isInvented)
         {
-            auto& gameState = GetGameState();
+            auto& gameState = getGameState();
             _selectedResearchItem = nullptr;
-            Invalidate();
+            invalidate();
 
             uint32_t beforeItemRawValue = 0;
             if (beforeItem != nullptr)
@@ -538,7 +532,7 @@ namespace OpenRCT2::Ui::Windows
 
             ResearchRemove(item);
 
-            auto& researchList = isInvented ? gameState.ResearchItemsInvented : gameState.ResearchItemsUninvented;
+            auto& researchList = isInvented ? gameState.researchItemsInvented : gameState.researchItemsUninvented;
             if (beforeItem != nullptr)
             {
                 for (size_t i = 0; i < researchList.size(); i++)
@@ -558,8 +552,8 @@ namespace OpenRCT2::Ui::Windows
     private:
         ResearchItem* GetItemFromScrollY(bool isInvented, int32_t y) const
         {
-            auto& gameState = GetGameState();
-            auto& researchList = isInvented ? gameState.ResearchItemsInvented : gameState.ResearchItemsUninvented;
+            auto& gameState = getGameState();
+            auto& researchList = isInvented ? gameState.researchItemsInvented : gameState.researchItemsUninvented;
             for (auto& researchItem : researchList)
             {
                 y -= kScrollableRowHeight;
@@ -574,8 +568,8 @@ namespace OpenRCT2::Ui::Windows
 
         ResearchItem* GetItemFromScrollYIncludeSeps(bool isInvented, int32_t y) const
         {
-            auto& gameState = GetGameState();
-            auto& researchList = isInvented ? gameState.ResearchItemsInvented : gameState.ResearchItemsUninvented;
+            auto& gameState = getGameState();
+            auto& researchList = isInvented ? gameState.researchItemsInvented : gameState.researchItemsUninvented;
             for (auto& researchItem : researchList)
             {
                 y -= kScrollableRowHeight;
@@ -596,7 +590,8 @@ namespace OpenRCT2::Ui::Windows
     {
         auto* windowMgr = GetWindowManager();
         return windowMgr->FocusOrCreate<InventionListWindow>(
-            WindowClass::EditorInventionList, WW, WH, WF_NO_SCROLLING | WF_RESIZABLE | WF_CENTRE_SCREEN);
+            WindowClass::editorInventionList, kWindowSize,
+            { WindowFlag::noScrolling, WindowFlag::resizable, WindowFlag::centreScreen });
     }
 #pragma endregion
 
@@ -607,17 +602,17 @@ namespace OpenRCT2::Ui::Windows
         ResearchItem _draggedItem;
 
     public:
-        void OnOpen() override
+        void onOpen() override
         {
-            SetWidgets(_inventionListDragWidgets);
+            setWidgets(_inventionListDragWidgets);
             colours[1] = COLOUR_WHITE;
         }
 
-        CursorID OnCursor(const WidgetIndex widx, const ScreenCoordsXY& screenCoords, const CursorID defaultCursor) override
+        CursorID onCursor(const WidgetIndex widx, const ScreenCoordsXY& screenCoords, const CursorID defaultCursor) override
         {
             auto* windowMgr = GetWindowManager();
             auto* inventionListWindow = static_cast<InventionListWindow*>(
-                windowMgr->FindByClass(WindowClass::EditorInventionList));
+                windowMgr->FindByClass(WindowClass::editorInventionList));
             if (inventionListWindow != nullptr)
             {
                 auto res = inventionListWindow->GetResearchItemAt(screenCoords);
@@ -625,21 +620,21 @@ namespace OpenRCT2::Ui::Windows
                 if (!inventionListWindow->IsResearchItemSelected(research))
                 {
                     inventionListWindow->SetSelectedResearchItem(research);
-                    inventionListWindow->Invalidate();
+                    inventionListWindow->invalidate();
                 }
             }
 
             return CursorID::HandClosed;
         }
 
-        void OnMoved(const ScreenCoordsXY& screenCoords) override
+        void onMoved(const ScreenCoordsXY& screenCoords) override
         {
             auto* windowMgr = GetWindowManager();
             auto* inventionListWindow = static_cast<InventionListWindow*>(
-                windowMgr->FindByClass(WindowClass::EditorInventionList));
+                windowMgr->FindByClass(WindowClass::editorInventionList));
             if (inventionListWindow == nullptr)
             {
-                Close();
+                close();
                 return;
             }
             std::optional<InventionListItem> res;
@@ -656,28 +651,28 @@ namespace OpenRCT2::Ui::Windows
                 inventionListWindow->MoveResearchItem(_draggedItem, res->research, res->isInvented);
             }
 
-            windowMgr->InvalidateByClass(WindowClass::EditorInventionList);
-            Close();
+            windowMgr->InvalidateByClass(WindowClass::editorInventionList);
+            close();
         }
 
-        void OnDraw(DrawPixelInfo& dpi) override
+        void onDraw(Drawing::RenderTarget& rt) override
         {
             auto screenCoords = windowPos + ScreenCoordsXY{ 0, 2 };
 
             DrawResearchItem(
-                dpi, _draggedItem, width, screenCoords, STR_WINDOW_COLOUR_2_STRINGID,
+                rt, _draggedItem, width, screenCoords, STR_WINDOW_COLOUR_2_STRINGID,
                 { ColourWithFlags{ COLOUR_BLACK }.withFlag(ColourFlag::withOutline, true) });
         }
 
-        void Init(ResearchItem& researchItem, const ScreenCoordsXY& editorPos, int objectSelectionScrollWidth)
+        void init(ResearchItem& researchItem, const ScreenCoordsXY& editorPos, int objectSelectionScrollWidth)
         {
             _draggedItem = researchItem;
 
             widgets[0].right = objectSelectionScrollWidth;
-            Invalidate();
+            invalidate();
             windowPos = ScreenCoordsXY{ editorPos.x, gTooltipCursor.y - 7 };
             width = objectSelectionScrollWidth;
-            Invalidate();
+            invalidate();
 
             InputWindowPositionBegin(*this, 0, gTooltipCursor);
         }
@@ -692,19 +687,20 @@ namespace OpenRCT2::Ui::Windows
         ResearchItem* researchItem, const ScreenCoordsXY& editorPos, int objectSelectionScrollWidth)
     {
         auto* windowMgr = Ui::GetWindowManager();
-        windowMgr->CloseByClass(WindowClass::EditorInventionListDrag);
+        windowMgr->CloseByClass(WindowClass::editorInventionListDrag);
         auto* wnd = windowMgr->Create<InventionDragWindow>(
-            WindowClass::EditorInventionListDrag, 10, 14, WF_STICK_TO_FRONT | WF_TRANSPARENT | WF_NO_SNAPPING);
+            WindowClass::editorInventionListDrag, { 10, 14 },
+            { WindowFlag::stickToFront, WindowFlag::transparent, WindowFlag::noSnapping });
         if (wnd != nullptr)
         {
-            wnd->Init(*researchItem, editorPos, objectSelectionScrollWidth);
+            wnd->init(*researchItem, editorPos, objectSelectionScrollWidth);
         }
     }
 
     static const ResearchItem* WindowEditorInventionsListDragGetItem()
     {
         auto* windowMgr = GetWindowManager();
-        auto* wnd = static_cast<InventionDragWindow*>(windowMgr->FindByClass(WindowClass::EditorInventionListDrag));
+        auto* wnd = static_cast<InventionDragWindow*>(windowMgr->FindByClass(WindowClass::editorInventionListDrag));
         if (wnd == nullptr)
         {
             return nullptr;
